@@ -1,7 +1,5 @@
 /// html_sql/py_sql impled
 #[macro_export]
 macro_rules! impled {
-    ()=>{
-        todo!()
-    }
+    ()=>{}
 }
\ No newline at end of file
